aboutsummaryrefslogtreecommitdiff
path: root/packages/aml-backoffice-ui/src/forms/902_13e.ts
diff options
context:
space:
mode:
authorSebastian <sebasjm@gmail.com>2024-01-03 14:52:00 -0300
committerSebastian <sebasjm@gmail.com>2024-01-03 14:52:00 -0300
commit1a71cd5ba2e9afb0ba7ef22760ecbe8b44aad953 (patch)
tree7d73293db6dca3ce0ac89d36a52472bd75fa8aa4 /packages/aml-backoffice-ui/src/forms/902_13e.ts
parent609ad091e332e4150b4d472284e5a9518cbe7571 (diff)
downloadwallet-core-1a71cd5ba2e9afb0ba7ef22760ecbe8b44aad953.tar.xz
split forms js
Diffstat (limited to 'packages/aml-backoffice-ui/src/forms/902_13e.ts')
-rw-r--r--packages/aml-backoffice-ui/src/forms/902_13e.ts138
1 files changed, 69 insertions, 69 deletions
diff --git a/packages/aml-backoffice-ui/src/forms/902_13e.ts b/packages/aml-backoffice-ui/src/forms/902_13e.ts
index 83ce88624..dce81bc5e 100644
--- a/packages/aml-backoffice-ui/src/forms/902_13e.ts
+++ b/packages/aml-backoffice-ui/src/forms/902_13e.ts
@@ -1,18 +1,18 @@
-import { AbsoluteTime, TranslatedString } from "@gnu-taler/taler-util";
-import { FlexibleForm, FormState } from "@gnu-taler/web-util/browser";
-import { BaseForm, } from "../pages/AntiMoneyLaunderingForm.js";
+import type { AbsoluteTime } from "@gnu-taler/taler-util";
+import type { FlexibleForm, FormState, InternationalizationAPI } from "@gnu-taler/web-util/browser";
+import { BaseForm } from "./index.js";
import { resolutionSection } from "./simplest.js";
-export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
+export const v1 = (i18n: InternationalizationAPI) => (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
design: [
{
- title: "Declaration for trusts" as TranslatedString,
+ title: i18n.str`Declaration for trusts`,
fields: [
{
type: "textArea",
props: {
name: "contractingPartner",
- label: "Contracting partner" as TranslatedString,
+ label: i18n.str`Contracting partner`,
},
},
{
@@ -20,7 +20,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "knownAs",
label:
- "The undersigned hereby declare(s) that as trustee or a member of highest supervisory body of an underlying company of a trust known as" as TranslatedString,
+ i18n.str`The undersigned hereby declare(s) that as trustee or a member of highest supervisory body of an underlying company of a trust known as`,
},
},
{
@@ -28,21 +28,21 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "trust.name",
label:
- "Name and information pertaining to the trust" as TranslatedString,
+ i18n.str`Name and information pertaining to the trust`,
},
},
{
type: "choiceStacked",
props: {
name: "trust.type",
- label: "Type of trust" as TranslatedString,
+ label: i18n.str`Type of trust`,
choices: [
{
- label: "Discretionary trust" as TranslatedString,
+ label: i18n.str`Discretionary trust`,
value: "discretionary",
},
{
- label: "Non-discretionary trust" as TranslatedString,
+ label: i18n.str`Non-discretionary trust`,
value: "non-discretionary",
},
],
@@ -52,14 +52,14 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "choiceStacked",
props: {
name: "trust.revocability",
- label: "Revocability" as TranslatedString,
+ label: i18n.str`Revocability`,
choices: [
{
- label: "Revocable foundation" as TranslatedString,
+ label: i18n.str`Revocable foundation`,
value: "revocable",
},
{
- label: "Irrevocable foundation" as TranslatedString,
+ label: i18n.str`Irrevocable foundation`,
value: "irrevocable",
},
],
@@ -69,7 +69,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "array",
props: {
label:
- "Information pertaining to the (ultimate economic, not fiduciary) settlor of the trust (individual(s) or entity/ies)" as TranslatedString,
+ i18n.str`Information pertaining to the (ultimate economic, not fiduciary) settlor of the trust (individual(s) or entity/ies)`,
labelField: "fullName",
name: "settlors",
fields: [
@@ -78,7 +78,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "fullName",
label:
- "Last name(s), first name(s)/entity" as TranslatedString,
+ i18n.str`Last name(s), first name(s)/entity`,
},
},
{
@@ -86,40 +86,40 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "address",
label:
- "Actual address of domicile/registered office" as TranslatedString,
+ i18n.str`Actual address of domicile/registered office`,
},
},
{
type: "text",
props: {
name: "country",
- label: "Country" as TranslatedString,
+ label: i18n.str`Country`,
},
},
{
type: "absoluteTime",
props: {
name: "dateOfBirth",
- label: "Date of birth" as TranslatedString,
+ label: i18n.str`Date of birth`,
pattern: "dd/MM/yyyy",
- // help: "format 'dd/MM/yyyy'" as TranslatedString,
+ // help: i18n.str`format 'dd/MM/yyyy'`,
},
},
{
type: "text",
props: {
name: "nationality",
- label: "Nationality" as TranslatedString,
+ label: i18n.str`Nationality`,
},
},
{
type: "absoluteTime",
props: {
name: "dateOfDeath",
- label: "Date of death" as TranslatedString,
+ label: i18n.str`Date of death`,
pattern: "dd/MM/yyyy",
- // help: "if deceased. format 'dd/MM/yyyy'" as TranslatedString,
- help: "if deceased'" as TranslatedString,
+ // help: i18n.str`if deceased. format 'dd/MM/yyyy'`,
+ help: i18n.str`if deceased'`,
},
},
{
@@ -128,14 +128,14 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
name: "rightToRevoke",
required: true,
label:
- "Does the founder have the right to revoke the trust?" as TranslatedString,
+ i18n.str`Does the founder have the right to revoke the trust?`,
choices: [
{
- label: "Yes" as TranslatedString,
+ label: i18n.str`Yes`,
value: "yes",
},
{
- label: "No" as TranslatedString,
+ label: i18n.str`No`,
value: "no",
},
],
@@ -148,7 +148,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "array",
props: {
label:
- "If the trust results from the restructuring of pre-existing trust (re-settlement) or the merger of pre-existing trusts, the following information pertaining to the (actual) settlor of the pre-existing trust(s) has to be given" as TranslatedString,
+ i18n.str`If the trust results from the restructuring of pre-existing trust (re-settlement) or the merger of pre-existing trusts, the following information pertaining to the (actual) settlor of the pre-existing trust(s) has to be given`,
labelField: "fullName",
name: "preExistingSettlors",
fields: [
@@ -157,7 +157,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "fullName",
label:
- "Last name(s), first name(s)/entity" as TranslatedString,
+ i18n.str`Last name(s), first name(s)/entity`,
},
},
{
@@ -165,40 +165,40 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "address",
label:
- "Actual address of domicile/registered office" as TranslatedString,
+ i18n.str`Actual address of domicile/registered office`,
},
},
{
type: "text",
props: {
name: "country",
- label: "Country" as TranslatedString,
+ label: i18n.str`Country`,
},
},
{
type: "absoluteTime",
props: {
name: "dateOfBirth",
- label: "Date of birth" as TranslatedString,
+ label: i18n.str`Date of birth`,
pattern: "dd/MM/yyyy",
- // help: "format 'dd/MM/yyyy'" as TranslatedString,
+ // help: i18n.str`format 'dd/MM/yyyy'`,
},
},
{
type: "text",
props: {
name: "nationality",
- label: "Nationality" as TranslatedString,
+ label: i18n.str`Nationality`,
},
},
{
type: "absoluteTime",
props: {
name: "dateOfDeath",
- label: "Date of death" as TranslatedString,
+ label: i18n.str`Date of death`,
pattern: "dd/MM/yyyy",
- help: "if deceased." as TranslatedString,
- // help: "if deceased. format 'dd/MM/yyyy'" as TranslatedString,
+ help: i18n.str`if deceased.`,
+ // help: i18n.str`if deceased. format 'dd/MM/yyyy'`,
},
},
],
@@ -208,7 +208,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "array",
props: {
label:
- "Pertaining to the beneficiary/-ies at the time of the signing of this form" as TranslatedString,
+ i18n.str`Pertaining to the beneficiary/-ies at the time of the signing of this form`,
labelField: "fullName",
name: "beneficiaryWhenSigning",
fields: [
@@ -217,7 +217,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "fullName",
label:
- "Last name(s), first name(s)/entity" as TranslatedString,
+ i18n.str`Last name(s), first name(s)/entity`,
},
},
{
@@ -225,30 +225,30 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "address",
label:
- "Actual address of domicile/registered office" as TranslatedString,
+ i18n.str`Actual address of domicile/registered office`,
},
},
{
type: "text",
props: {
name: "country",
- label: "Country" as TranslatedString,
+ label: i18n.str`Country`,
},
},
{
type: "absoluteTime",
props: {
name: "dateOfBirth",
- label: "Date of birth" as TranslatedString,
+ label: i18n.str`Date of birth`,
pattern: "dd/MM/yyyy",
- // help: "format 'dd/MM/yyyy'" as TranslatedString,
+ // help: i18n.str`format 'dd/MM/yyyy'`,
},
},
{
type: "text",
props: {
name: "nationality",
- label: "Nationality" as TranslatedString,
+ label: i18n.str`Nationality`,
},
},
{
@@ -256,14 +256,14 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "rightToClaim",
label:
- "Has the beneficiary an actual right to claim distribution?" as TranslatedString,
+ i18n.str`Has the beneficiary an actual right to claim distribution?`,
choices: [
{
- label: "Yes" as TranslatedString,
+ label: i18n.str`Yes`,
value: "yes",
},
{
- label: "No" as TranslatedString,
+ label: i18n.str`No`,
value: "no",
},
],
@@ -273,7 +273,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "textArea",
props: {
label:
- "in addition to certain beneficiaries or if there is/are no defined beneficiary/ies pertaining to (a) group(s) of beneficiaries (e.g. descendants of the settlor) known at the time of the signing of this form" as TranslatedString,
+ i18n.str`in addition to certain beneficiaries or if there is/are no defined beneficiary/ies pertaining to (a) group(s) of beneficiaries (e.g. descendants of the settlor) known at the time of the signing of this form`,
name: "beneficiaryExtra",
},
},
@@ -284,7 +284,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "array",
props: {
label:
- "Information pertaining to the protector(s) as well as (a) further person(s) having the right to revoke the trust (in case of revocable trusts) or to appoint the trustee of a trust" as TranslatedString,
+ i18n.str`Information pertaining to the protector(s) as well as (a) further person(s) having the right to revoke the trust (in case of revocable trusts) or to appoint the trustee of a trust`,
labelField: "asd",
name: "nothing",
fields: [],
@@ -295,7 +295,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "array",
props: {
label:
- "Information pertaining to the protectors" as TranslatedString,
+ i18n.str`Information pertaining to the protectors`,
labelField: "fullName",
name: "protectors",
fields: [
@@ -304,7 +304,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "fullName",
label:
- "Last name(s), first name(s)/entity" as TranslatedString,
+ i18n.str`Last name(s), first name(s)/entity`,
},
},
{
@@ -312,28 +312,28 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "address",
label:
- "Actual address of domicile/registered office" as TranslatedString,
+ i18n.str`Actual address of domicile/registered office`,
},
},
{
type: "text",
props: {
name: "country",
- label: "Country" as TranslatedString,
+ label: i18n.str`Country`,
},
},
{
type: "text",
props: {
name: "dateOfBirth",
- label: "Date of birth" as TranslatedString,
+ label: i18n.str`Date of birth`,
},
},
{
type: "text",
props: {
name: "nationality",
- label: "Nationality" as TranslatedString,
+ label: i18n.str`Nationality`,
},
},
{
@@ -341,14 +341,14 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "rightToClaim",
label:
- "Does the protector have the right to revoke the trust?" as TranslatedString,
+ i18n.str`Does the protector have the right to revoke the trust?`,
choices: [
{
- label: "Yes" as TranslatedString,
+ label: i18n.str`Yes`,
value: "yes",
},
{
- label: "No" as TranslatedString,
+ label: i18n.str`No`,
value: "no",
},
],
@@ -361,7 +361,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "array",
props: {
label:
- "Information pertaining to further persons" as TranslatedString,
+ i18n.str`Information pertaining to further persons`,
labelField: "fullName",
name: "furtherPersons",
fields: [
@@ -370,7 +370,7 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "fullName",
label:
- "Last name(s), first name(s)/entity" as TranslatedString,
+ i18n.str`Last name(s), first name(s)/entity`,
},
},
{
@@ -378,28 +378,28 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "address",
label:
- "Actual address of domicile/registered office" as TranslatedString,
+ i18n.str`Actual address of domicile/registered office`,
},
},
{
type: "text",
props: {
name: "country",
- label: "Country" as TranslatedString,
+ label: i18n.str`Country`,
},
},
{
type: "text",
props: {
name: "dateOfBirth",
- label: "Date of birth" as TranslatedString,
+ label: i18n.str`Date of birth`,
},
},
{
type: "text",
props: {
name: "nationality",
- label: "Nationality" as TranslatedString,
+ label: i18n.str`Nationality`,
},
},
{
@@ -407,14 +407,14 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
props: {
name: "rightToClaim",
label:
- "Has this further person the right to revoke the trust?" as TranslatedString,
+ i18n.str`Has this further person the right to revoke the trust?`,
choices: [
{
- label: "Yes" as TranslatedString,
+ label: i18n.str`Yes`,
value: "yes",
},
{
- label: "No" as TranslatedString,
+ label: i18n.str`No`,
value: "no",
},
],
@@ -427,12 +427,12 @@ export const v1 = (current: BaseForm): FlexibleForm<Form902_13.Form> => ({
type: "text",
props: {
name: "signature",
- label: "Signature" as TranslatedString,
+ label: i18n.str`Signature`,
},
},
],
},
- resolutionSection(current),
+ resolutionSection(current, i18n),
],
behavior: function formBehavior(
v: Partial<Form902_13.Form>,